@@ -17,16 +17,20 @@ from __future__ import print_function
 import sys
 import time
 
-from cinderclient import utils
 from cinderclient import exceptions
+from cinderclient import utils
 
 _quota_resources = ['volumes', 'snapshots', 'gigabytes',
                     'backups', 'backup_gigabytes',
                     'per_volume_gigabytes', 'groups', ]
-_quota_infos = ['Type', 'In_use', 'Reserved', 'Limit']
+_quota_infos = ['Type', 'In_use', 'Reserved', 'Limit', 'Allocated']
 
 
 def print_volume_image(image):
+    if 'volume_type' in image[1]['os-volume_upload_image']:
+        volume_type_name = (
+            image[1]['os-volume_upload_image']['volume_type']['name'])
+        image[1]['os-volume_upload_image']['volume_type'] = volume_type_name
     utils.print_dict(image[1]['os-volume_upload_image'])
 
 
@@ -238,6 +242,9 @@ def quota_update(manager, identifier, args):
             updates[resource] = val
 
     if updates:
+        skip_validation = getattr(args, 'skip_validation', True)
+        if not skip_validation:
+            updates['skip_validation'] = skip_validation
         quota_show(manager.update(identifier, **updates))
 
 
